/***************************************************************************
                               xyce_script.h
                                ----------
    begin                : Wed Jun 22 2016
    copyright            : (C) 2016 by Vadim Kuznetsov
    email                : ra3xdh@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SP_XYCESCRIPT_H
#define SP_XYCESCRIPT_H

#include "components/simulation.h"


class XyceScript : public qucs::component::SimulationComponent  {
public:
  XyceScript();
  ~XyceScript();
  Component* newOne();
  static Element* info(QString&, char* &, bool getNewOne=false);

protected:
  QString spice_netlist(spicecompat::SpiceDialect dialect = spicecompat::SPICEDefault);
  Qt::GlobalColor color() const override { return Qt::darkGreen; }
};

#endif
